@@ -1,9 +1,11 @@
+from .Chat import Chat
 from .DashpoolProvider import DashpoolProvider
 from .Explorer import Explorer
 from .History import History
 from .Loader import Loader
 
 __all__ = [
+    "Chat",
     "DashpoolProvider",
     "Explorer",
     "History",
